from requests import get
from bs4 import BeautifulSoup


def search(term, num_results=10, lang="en"):
    usr_agent = {
        'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) '
                      'Chrome/61.0.3163.100 Safari/537.36'}

    def fetch_results(search_term, number_results, language_code):
        escaped_search_term = search_term.replace(' ', '+')

        google_url = 'https://www.google.com/search?q={}&num={}&hl={}'.format(escaped_search_term, number_results+1,
                                                                              language_code)
        response = get(google_url, headers=usr_agent)
        response.raise_for_status()

        return response.text

    def parse_results(raw_html):
        soup = BeautifulSoup(raw_html, 'html.parser')
        result_block = soup.find_all('div', attrs={'class': 'g'})
        for result in result_block:
            link = result.find('a', href=True)
            title = result.find('h3')
            if link and title:
                yield link['href']

    html = fetch_results(term, num_results, lang)
    return list(parse_results(html))



from bs4 import BeautifulSoup
from urllib.request import urlopen
import requests

class anime:

    def __init__(self, query):

        if " " in query:
            query = query.replace(" ", "%20")

        to_open = f"https://myanimelist.net/anime.php?q={query}"

        try:
            html_page = urlopen(to_open)
        except UnicodeEncodeError:
            encoded_url = to_open.encode('ascii','ignore')
            html_page = urlopen(str(encoded_url))
        
        soup = BeautifulSoup(html_page, 'html.parser')

        anime_div = soup.find("td", {'class': 'borderClass bgColor0'})
        url = anime_div.find("a", href = True)

        self.url = url['href']

    def recommend(self, amount: int = 5):

        if amount >= 10:
            print("Keep requests below 10 to avoid stressing the API.")
            return

        anime_page = urlopen(f"{self.url}/userrecs")
        soup = BeautifulSoup(anime_page, 'html.parser')

        headers = soup.findAll("strong")

        recommendations = []

        for i in headers:
            recommendations.append(i.get_text())

        ri = [i for i in recommendations if not i.isdigit()]  
        ri.pop(0)

        return ri[:amount]

def waifu(category = "waifu"):
    
    url = requests.get(f"https://waifu.pics/api/sfw/{category}")
    image = url.json()['url']

    return image


import animec.gs
from bs4 import BeautifulSoup
from urllib.request import urlopen
import re

class charsearch:
    
    def __init__(self, query):

        url = find_character(query)

        if url is None:
            raise NoCharacterFound
            return

        html_page = urlopen(url)
        soup = BeautifulSoup(html_page, 'html.parser')

        images = soup.findAll('img')

        string_list = [str(i) for i in images]

        for k in string_list:
            if 'characters' in k:
                char = k
                break

        image_url = re.search("https://.*jpg", char).group()

        title = soup.find('h2')
        title = title.get_text()

        self.title = title
        self.url = url
        self.image_url = image_url

class NoCharacterFound(Exception):
    pass

def find_character(query):

    for url in animec.gs.search(f"{query} anime character info", num_results = 50):
        if ('myanimelist' in str(url)) and ('character' in str(url)):
            return url